@@ -54,7 +54,7 @@ except ModuleNotFoundError:
 from . import logging
 from .acquisition.rule import AcquisitionRule, EfficientGlobalOptimization
 from .data import Dataset
-from .models import TrainableProbabilisticModel
+from .models import SupportsCovarianceWithTopFidelity, TrainableProbabilisticModel
 from .observer import OBJECTIVE, Observer
 from .space import SearchSpace
 from .types import State, Tag, TensorType
@@ -229,6 +229,13 @@ class OptimizationResult(Generic[StateType]):
         dataset = self.try_get_final_dataset()
         if tf.rank(dataset.observations) != 2 or dataset.observations.shape[1] != 1:
             raise ValueError("Expected a single objective")
+        if tf.reduce_any(
+            [
+                isinstance(model, SupportsCovarianceWithTopFidelity)
+                for model in self.try_get_final_models()
+            ]
+        ):
+            raise ValueError("Expected single fidelity models")
         arg_min_idx = tf.squeeze(tf.argmin(dataset.observations, axis=0))
         return dataset.query_points[arg_min_idx], dataset.observations[arg_min_idx], arg_min_idx
 
@@ -635,7 +642,6 @@ class BayesianOptimizer(Generic[SearchSpaceType]):
                 break
 
             try:
-
                 if track_state:
                     try:
                         if track_path is None:
@@ -800,7 +806,6 @@ def observation_plot_init(
     Also logs warnings if pairplot dependencies are not installed."""
     observation_plot_dfs: dict[Tag, pd.DataFrame] = {}
     if logging.get_tensorboard_writer():
-
         seaborn_warning = False
         if logging.include_summary("query_points/_pairplot") and not (pd and sns):
             seaborn_warning = True
@@ -835,7 +840,6 @@ def write_summary_observations(
 ) -> None:
     """Write TensorBoard summary for the current step observations."""
     for tag in datasets:
-
         with tf.name_scope(f"{tag}.model"):
             models[tag].log(datasets[tag])
 
