@@ -42,6 +42,7 @@ from ...utils.misc import flatten_leading_dims
 from ..interfaces import (
     FastUpdateModel,
     HasTrajectorySampler,
+    SupportsCovarianceWithTopFidelity,
     SupportsGetInducingVariables,
     SupportsGetInternalData,
     TrainableProbabilisticModel,
@@ -386,7 +387,7 @@ class GaussianProcessRegression(
         L_add = tf.linalg.cholesky(cov_add + noise)  # [..., L, N, N]
         A = tf.linalg.triangular_solve(L_add, cov_cross, lower=True)  # [..., L, N, M]
         var_qp_new = var_qp - leading_transpose(
-            tf.reduce_sum(A ** 2, axis=-2), [..., -1, -2]
+            tf.reduce_sum(A**2, axis=-2), [..., -1, -2]
         )  # [..., M, L]
 
         mean_add_diff = additional_data.observations - mean_add  # [..., N, L]
@@ -960,7 +961,6 @@ class SparseVariational(
         num_data = dataset.query_points.shape[0]
         assert self.model.num_data is not None
         self.model.num_data.assign(num_data)
-        self.update_posterior_cache()
 
         if self._inducing_point_selector is not None:
             new_inducing_points = self._inducing_point_selector.calculate_inducing_points(
@@ -973,6 +973,7 @@ class SparseVariational(
                 )
             ):  # only bother updating if points actually change
                 self._update_inducing_variables(new_inducing_points)
+                self.update_posterior_cache()
 
     def optimize(self, dataset: Dataset) -> None:
         """
@@ -1012,6 +1013,7 @@ class SparseVariational(
             new_q_mu, new_q_sqrt = _whiten_points(self, new_inducing_points)
         else:
             new_q_mu, new_f_cov = self.predict_joint(new_inducing_points)  # [N, L], [L, N, N]
+            new_q_mu -= self.model.mean_function(new_inducing_points)
             jitter_mat = DEFAULTS.JITTER * tf.eye(
                 tf.shape(new_inducing_points)[0], dtype=new_f_cov.dtype
             )
@@ -1213,7 +1215,6 @@ class VariationalGaussianProcess(
 
         model = self.model
         if not all(isinstance(x, tf.Variable) and x.shape[0] is None for x in model.data):
-
             variable_data = (
                 tf.Variable(
                     model.data[0],
@@ -1277,7 +1278,6 @@ class VariationalGaussianProcess(
         model = self.model
 
         if self._use_natgrads:  # optimize variational params with natgrad optimizer
-
             natgrad_optimizer = gpflow.optimizers.NaturalGradient(gamma=self._natgrad_gamma)
             base_optimizer = self.optimizer
 
@@ -1370,7 +1370,7 @@ class VariationalGaussianProcess(
         )
 
 
-class MultifidelityAutoregressive(TrainableProbabilisticModel):
+class MultifidelityAutoregressive(TrainableProbabilisticModel, SupportsCovarianceWithTopFidelity):
     r"""
     A :class:`TrainableProbabilisticModel` implementation of the model
     from :cite:`Kennedy2000`. This is a multi-fidelity model that works with an
@@ -1396,7 +1396,7 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
             for the lowest fidelity and models at higher indices will be used as the residual
             model for each higher fidelity.
         """
-        self.num_fidelities = len(fidelity_models)
+        self._num_fidelities = len(fidelity_models)
 
         self.lowest_fidelity_signal_model = fidelity_models[0]
         # Note: The 0th index in the below is not a residual model, and should not be used.
@@ -1411,6 +1411,10 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
             *rho,
         ]
 
+    @property
+    def num_fidelities(self) -> int:
+        return self._num_fidelities
+
     def predict(self, query_points: TensorType) -> tuple[TensorType, TensorType]:
         """
         Predict the marginal mean and variance at query_points.
@@ -1431,10 +1435,15 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
             query_points_wo_fidelity
         )  # [..., N, P], [..., N, P]
 
-        for fidelity in range(1, int(tf.reduce_max(query_points_fidelity_col)) + 1):
+        for fidelity, (fidelity_residual_model, rho) in enumerate(
+            zip(self.fidelity_residual_models, self.rho)
+        ):
+            if fidelity == 0:
+                continue
 
             # Find indices of query points that need predicting for
-            mask = query_points_fidelity_col >= fidelity  # [..., N, 1]
+            fidelity_float = tf.cast(fidelity, query_points.dtype)
+            mask = query_points_fidelity_col >= fidelity_float  # [..., N, 1]
             fidelity_indices = tf.where(mask)[..., :-1]
             # Gather necessary query points and  predict
             fidelity_filtered_query_points = tf.gather_nd(
@@ -1443,7 +1452,7 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
             (
                 filtered_fidelity_residual_mean,
                 filtered_fidelity_residual_var,
-            ) = self.fidelity_residual_models[fidelity].predict(fidelity_filtered_query_points)
+            ) = fidelity_residual_model.predict(fidelity_filtered_query_points)
 
             # Scatter predictions back into correct location
             fidelity_residual_mean = tf.tensor_scatter_nd_update(
@@ -1454,11 +1463,11 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
             )
 
             # Calculate mean and var for all columns (will be incorrect for qps with fid < fidelity)
-            new_fidelity_signal_mean = self.rho[fidelity] * signal_mean + fidelity_residual_mean
-            new_fidelity_signal_var = fidelity_residual_var + (self.rho[fidelity] ** 2) * signal_var
+            new_fidelity_signal_mean = rho * signal_mean + fidelity_residual_mean
+            new_fidelity_signal_var = fidelity_residual_var + (rho**2) * signal_var
 
             # Mask out incorrect values and update mean and var for correct ones
-            mask = query_points_fidelity_col >= fidelity
+            mask = query_points_fidelity_col >= fidelity_float
             signal_mean = tf.where(mask, new_fidelity_signal_mean, signal_mean)
             signal_var = tf.where(mask, new_fidelity_signal_var, signal_var)
 
@@ -1507,7 +1516,6 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
         )  # [S, N, P]
 
         for fidelity in range(1, int(tf.reduce_max(query_points_fidelity_col)) + 1):
-
             fidelity_residual_sample = self.fidelity_residual_models[fidelity].sample(
                 query_points_wo_fidelity, num_samples
             )
@@ -1543,7 +1551,6 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
         )
 
         for fidelity in range(1, self.num_fidelities):
-
             fidelity_observation_noise = (
                 self.rho[fidelity] ** 2
             ) * observation_noise + self.fidelity_residual_models[fidelity].get_observation_noise()
@@ -1641,7 +1648,6 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
         _, f_var = self.predict(query_points)
 
         for fidelity in range(self.num_fidelities - 1, -1, -1):
-
             mask = fidelities < fidelity
 
             f_var = tf.where(mask, f_var, f_var * self.rho[fidelity])
@@ -1649,7 +1655,9 @@ class MultifidelityAutoregressive(TrainableProbabilisticModel):
         return f_var
 
 
-class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
+class MultifidelityNonlinearAutoregressive(
+    TrainableProbabilisticModel, SupportsCovarianceWithTopFidelity
+):
     r"""
     A :class:`TrainableProbabilisticModel` implementation of the model from
     :cite:`perdikaris2017nonlinear`. This is a multifidelity model that works with
@@ -1679,12 +1687,16 @@ class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
             sections of prediction and sampling that require the use of Monte Carlo methods.
         """
 
-        self.num_fidelities = len(fidelity_models)
+        self._num_fidelities = len(fidelity_models)
         self.fidelity_models = fidelity_models
         self.monte_carlo_random_numbers = tf.random.normal(
             [num_monte_carlo_samples, 1], dtype=tf.float64
         )
 
+    @property
+    def num_fidelities(self) -> int:
+        return self._num_fidelities
+
     def sample(self, query_points: TensorType, num_samples: int) -> TensorType:
         """
         Return ``num_samples`` samples from the independent marginal distributions at
@@ -1710,7 +1722,6 @@ class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
         )  # [..., S, N, 1]
 
         for fidelity in range(1, self.num_fidelities):
-
             qp_repeated = tf.repeat(
                 query_points_wo_fidelity[..., None, :, :], num_samples, axis=-3
             )  # [..., S, N, D]
@@ -1769,7 +1780,6 @@ class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
         )
 
         for fidelity in range(1, self.num_fidelities):
-
             fidelity_observation_noise = self.fidelity_models[fidelity].get_observation_noise()
 
             mask = query_points_fidelity_col >= fidelity
@@ -1821,7 +1831,6 @@ class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
         # Predict for all fidelities but stop updating once we have
         # reached desired fidelity for each query point
         for fidelity in range(1, self.num_fidelities):
-
             # sample_mean [..., N, 1, S]
             # sample_var [..., N, 1, S]
             (
@@ -1918,7 +1927,6 @@ class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
             if fidelity == 0:
                 self.fidelity_models[0].update(dataset_for_fidelity)
             else:
-
                 cur_fidelity_model = self.fidelity_models[fidelity]
                 new_final_query_point_col, _ = self.predict(
                     add_fidelity_column(dataset_for_fidelity.query_points, fidelity - 1)
@@ -1989,7 +1997,6 @@ class MultifidelityNonlinearAutoregressive(TrainableProbabilisticModel):
         max_fidelity_sample = tf.identity(signal_sample)
 
         for fidelity in range(1, self.num_fidelities):
-
             qp_repeated = tf.repeat(
                 query_points_wo_fidelity[None, :, :], num_samples, axis=0
             )  # [S, N, D]
