@@ -31,7 +31,6 @@ import tensorflow_probability as tfp
 from ..data import Dataset
 from ..types import TensorType
 from ..utils import jit
-from .interfaces import TrainableProbabilisticModel
 
 TrainingData = Union[Tuple[TensorType, TensorType], Iterable[Tuple[TensorType, TensorType]]]
 """ Type alias for a batch, or batches, of training data. """
@@ -154,31 +153,31 @@ class BatchOptimizer(Optimizer):
 
 @dataclass
 class KerasOptimizer:
-    """Optimizer wrapper for training neural network models implemented with Keras."""
+    """Optimizer wrapper for training models implemented with Keras."""
 
     optimizer: tf.keras.optimizers.Optimizer
     """ The underlying optimizer to use for training the model. """
 
-    loss: Union[
-        tf.keras.losses.Loss, Callable[[TensorType, tfp.distributions.Distribution], TensorType]
-    ] = None
-    """ Defines the loss function for training the network. """
-
     fit_args: dict[str, Any] = field(default_factory=lambda: {})
     """
-    The keyword arguments to pass to the `fit` method of a :class:`~tf.keras.Model` instance.
+    The keyword arguments to pass to the ``fit`` method of a :class:`~tf.keras.Model` instance.
     See https://keras.io/api/models/model_training_apis/#fit-method for a list of possible
     arguments in the dictionary.
     """
 
+    loss: Optional[
+        Union[
+            tf.keras.losses.Loss, Callable[[TensorType, tfp.distributions.Distribution], TensorType]
+        ]
+    ] = None
+    """ Optional loss function for training the model. """
+
     metrics: Optional[list[tf.keras.metrics.Metric]] = None
     """ Optional metrics for monitoring the performance of the network. """
 
 
 @singledispatch
-def create_loss_function(
-    model: TrainableProbabilisticModel, dataset: TrainingData, compile: bool = False
-) -> LossClosure:
+def create_loss_function(model: Any, dataset: TrainingData, compile: bool = False) -> LossClosure:
     """
     Generic function for building a loss function for a specified `model` and `dataset`.
     The implementations depends on the type of the model, which should use this function as a
